@@ -3,15 +3,15 @@ use std::borrow::Cow;
 use twilight_model::{
     gateway::payload::incoming::GuildEmojisUpdate,
     guild::Emoji,
-    id::{EmojiId, GuildId},
+    id::{marker::GuildMarker, Id},
 };
 
 impl InMemoryCache {
-    pub(crate) fn cache_emojis(&self, guild_id: GuildId, emojis: Vec<Emoji>) {
+    pub(crate) fn cache_emojis(&self, guild_id: Id<GuildMarker>, emojis: Vec<Emoji>) {
         if let Some(mut guild_emojis) = self.guild_emojis.get_mut(&guild_id) {
-            let incoming: Vec<EmojiId> = emojis.iter().map(|e| e.id).collect();
+            let incoming: Vec<_> = emojis.iter().map(|e| e.id).collect();
 
-            let removal_filter: Vec<EmojiId> = guild_emojis
+            let removal_filter: Vec<_> = guild_emojis
                 .iter()
                 .copied()
                 .filter(|e| !incoming.contains(e))
@@ -31,7 +31,7 @@ impl InMemoryCache {
         }
     }
 
-    pub(crate) fn cache_emoji(&self, guild_id: GuildId, emoji: Emoji) {
+    pub(crate) fn cache_emoji(&self, guild_id: Id<GuildMarker>, emoji: Emoji) {
         match self.emojis.get(&emoji.id) {
             Some(cached_emoji) if cached_emoji.value == emoji => return,
             Some(_) | None => {}
@@ -83,17 +83,20 @@ impl UpdateCache for GuildEmojisUpdate {
 mod tests {
     use super::*;
     use crate::test;
-    use twilight_model::{id::UserId, user::User};
+    use twilight_model::{
+        id::{marker::EmojiMarker, Id},
+        user::User,
+    };
 
     #[test]
     fn test_cache_emoji() {
         let cache = InMemoryCache::new();
 
         // The user to do some of the inserts
-        fn user_mod(id: EmojiId) -> Option<User> {
+        fn user_mod(id: Id<EmojiMarker>) -> Option<User> {
             if id.get() % 2 == 0 {
                 // Only use user for half
-                Some(test::user(UserId::new(1).expect("non zero")))
+                Some(test::user(Id::new(1)))
             } else {
                 None
             }
@@ -101,9 +104,7 @@ mod tests {
 
         // Single inserts
         {
-            let guild_1_emoji_ids = (1..=10)
-                .map(|n| EmojiId::new(n).expect("non zero"))
-                .collect::<Vec<_>>();
+            let guild_1_emoji_ids = (1..=10).map(Id::new).collect::<Vec<_>>();
             let guild_1_emoji = guild_1_emoji_ids
                 .iter()
                 .copied()
@@ -111,7 +112,7 @@ mod tests {
                 .collect::<Vec<_>>();
 
             for emoji in guild_1_emoji {
-                cache.cache_emoji(GuildId::new(1).expect("non zero"), emoji);
+                cache.cache_emoji(Id::new(1), emoji);
             }
 
             for id in guild_1_emoji_ids.iter().cloned() {
@@ -121,7 +122,7 @@ mod tests {
 
             // Ensure the emoji has been added to the per-guild lookup map to prevent
             // issues like #551 from returning
-            let guild_emojis = cache.guild_emojis(GuildId::new(1).expect("non zero"));
+            let guild_emojis = cache.guild_emojis(Id::new(1));
             assert!(guild_emojis.is_some());
             let guild_emojis = guild_emojis.unwrap();
 
@@ -131,22 +132,20 @@ mod tests {
 
         // Bulk inserts
         {
-            let guild_2_emoji_ids = (11..=20)
-                .map(|n| EmojiId::new(n).expect("non zero"))
-                .collect::<Vec<_>>();
+            let guild_2_emoji_ids = (11..=20).map(Id::new).collect::<Vec<_>>();
             let guild_2_emojis = guild_2_emoji_ids
                 .iter()
                 .copied()
                 .map(|id| test::emoji(id, user_mod(id)))
                 .collect::<Vec<_>>();
-            cache.cache_emojis(GuildId::new(2).expect("non zero"), guild_2_emojis);
+            cache.cache_emojis(Id::new(2), guild_2_emojis);
 
             for id in guild_2_emoji_ids.iter().cloned() {
                 let global_emoji = cache.emoji(id);
                 assert!(global_emoji.is_some());
             }
 
-            let guild_emojis = cache.guild_emojis(GuildId::new(2).expect("non zero"));
+            let guild_emojis = cache.guild_emojis(Id::new(2));
 
             assert!(guild_emojis.is_some());
             let guild_emojis = guild_emojis.unwrap();
@@ -159,11 +158,11 @@ mod tests {
     fn test_emoji_removal() {
         let cache = InMemoryCache::new();
 
-        let guild_id = GuildId::new(1).expect("non zero");
+        let guild_id = Id::new(1);
 
-        let emote = test::emoji(EmojiId::new(1).expect("non zero"), None);
-        let emote_2 = test::emoji(EmojiId::new(2).expect("non zero"), None);
-        let emote_3 = test::emoji(EmojiId::new(3).expect("non zero"), None);
+        let emote = test::emoji(Id::new(1), None);
+        let emote_2 = test::emoji(Id::new(2), None);
+        let emote_3 = test::emoji(Id::new(3), None);
 
         cache.cache_emoji(guild_id, emote.clone());
         cache.cache_emoji(guild_id, emote_2.clone());
@@ -190,7 +189,7 @@ mod tests {
         assert!(cache.emoji(emote.id).is_some());
         assert!(cache.emoji(emote_2.id).is_none());
 
-        let emote_4 = test::emoji(EmojiId::new(4).expect("non zero"), None);
+        let emote_4 = test::emoji(Id::new(4), None);
 
         cache.update(&GuildEmojisUpdate {
             emojis: vec![emote_4.clone()],
