@@ -3,7 +3,11 @@ use twilight_model::{
     application::interaction::application_command::InteractionMember,
     datetime::Timestamp,
     guild::{Member, PartialMember},
-    id::{GuildId, RoleId, UserId},
+    id::{
+        marker::{GuildMarker, RoleMarker, UserMarker},
+        Id,
+    },
+    util::image_hash::ImageHash,
 };
 
 /// Represents a cached [`Member`].
@@ -11,23 +15,23 @@ use twilight_model::{
 /// [`Member`]: twilight_model::guild::Member
 #[derive(Clone, Debug, Eq, PartialEq, Serialize)]
 pub struct CachedMember {
-    pub(crate) avatar: Option<String>,
+    pub(crate) avatar: Option<ImageHash>,
     pub(crate) communication_disabled_until: Option<Timestamp>,
     pub(crate) deaf: Option<bool>,
-    pub(crate) guild_id: GuildId,
+    pub(crate) guild_id: Id<GuildMarker>,
     pub(crate) joined_at: Timestamp,
     pub(crate) mute: Option<bool>,
     pub(crate) nick: Option<String>,
     pub(crate) pending: bool,
     pub(crate) premium_since: Option<Timestamp>,
-    pub(crate) roles: Vec<RoleId>,
-    pub(crate) user_id: UserId,
+    pub(crate) roles: Vec<Id<RoleMarker>>,
+    pub(crate) user_id: Id<UserMarker>,
 }
 
 impl CachedMember {
     /// Member's guild avatar.
-    pub fn avatar(&self) -> Option<&str> {
-        self.avatar.as_deref()
+    pub const fn avatar(&self) -> Option<ImageHash> {
+        self.avatar
     }
 
     /// When the user can resume communication in a guild again.
@@ -49,7 +53,7 @@ impl CachedMember {
     }
 
     /// ID of the guild this member is a part of.
-    pub const fn guild_id(&self) -> GuildId {
+    pub const fn guild_id(&self) -> Id<GuildMarker> {
         self.guild_id
     }
 
@@ -80,12 +84,12 @@ impl CachedMember {
     }
 
     /// List of role IDs this member has.
-    pub fn roles(&self) -> &[RoleId] {
+    pub fn roles(&self) -> &[Id<RoleMarker>] {
         &self.roles
     }
 
     /// ID of the user relating to the member.
-    pub const fn user_id(&self) -> UserId {
+    pub const fn user_id(&self) -> Id<UserMarker> {
         self.user_id
     }
 }
@@ -133,7 +137,7 @@ mod tests {
     use twilight_model::{
         datetime::Timestamp,
         guild::{Member, PartialMember},
-        id::{GuildId, UserId},
+        id::Id,
         user::User,
     };
 
@@ -156,7 +160,7 @@ mod tests {
             avatar: None,
             communication_disabled_until: None,
             deaf: Some(false),
-            guild_id: GuildId::new(3).expect("non zero"),
+            guild_id: Id::new(3),
             joined_at,
             mute: Some(true),
             nick: Some("member nick".to_owned()),
@@ -176,7 +180,7 @@ mod tests {
             discriminator: 1,
             email: None,
             flags: None,
-            id: UserId::new(1).expect("non zero"),
+            id: Id::new(1),
             locale: None,
             mfa_enabled: None,
             name: "bar".to_owned(),
@@ -195,7 +199,7 @@ mod tests {
             avatar: None,
             communication_disabled_until: None,
             deaf: false,
-            guild_id: GuildId::new(3).expect("non zero"),
+            guild_id: Id::new(3),
             joined_at,
             mute: true,
             nick: Some("member nick".to_owned()),
