@@ -7,14 +7,19 @@ use twilight_model::{
     datetime::Timestamp,
     gateway::payload::incoming::{MessageCreate, ReactionAdd},
     guild::{Emoji, Member, PartialMember, Permissions, Role},
-    id::{ChannelId, EmojiId, GuildId, MessageId, RoleId, UserId},
+    id::{
+        marker::{ChannelMarker, EmojiMarker, GuildMarker, RoleMarker, UserMarker},
+        Id,
+    },
     user::{CurrentUser, User},
+    util::image_hash::ImageHash,
     voice::VoiceState,
 };
 
 pub fn cache_with_message_and_reactions() -> InMemoryCache {
     let joined_at = Timestamp::from_secs(1_632_072_645).expect("non zero");
     let cache = InMemoryCache::new();
+    let avatar = ImageHash::parse(b"6961d9f1fdb5880bf4a3ec6348d3bbcf").unwrap();
 
     let msg = Message {
         activity: None,
@@ -23,13 +28,13 @@ pub fn cache_with_message_and_reactions() -> InMemoryCache {
         attachments: Vec::new(),
         author: User {
             accent_color: None,
-            avatar: Some("".to_owned()),
+            avatar: Some(avatar),
             banner: None,
             bot: false,
             discriminator: 1,
             email: None,
             flags: None,
-            id: UserId::new(3).expect("non zero"),
+            id: Id::new(3),
             locale: None,
             mfa_enabled: None,
             name: "test".to_owned(),
@@ -38,14 +43,14 @@ pub fn cache_with_message_and_reactions() -> InMemoryCache {
             system: None,
             verified: None,
         },
-        channel_id: ChannelId::new(2).expect("non zero"),
+        channel_id: Id::new(2),
         components: Vec::new(),
         content: "ping".to_owned(),
         edited_timestamp: None,
         embeds: Vec::new(),
         flags: Some(MessageFlags::empty()),
-        guild_id: Some(GuildId::new(1).expect("non zero")),
-        id: MessageId::new(4).expect("non zero"),
+        guild_id: Some(Id::new(1)),
+        id: Id::new(4),
         interaction: None,
         kind: MessageType::Regular,
         member: Some(PartialMember {
@@ -78,16 +83,16 @@ pub fn cache_with_message_and_reactions() -> InMemoryCache {
     cache.update(&MessageCreate(msg));
 
     let mut reaction = ReactionAdd(Reaction {
-        channel_id: ChannelId::new(2).expect("non zero"),
+        channel_id: Id::new(2),
         emoji: ReactionType::Unicode {
             name: "😀".to_owned(),
         },
-        guild_id: Some(GuildId::new(1).expect("non zero")),
+        guild_id: Some(Id::new(1)),
         member: Some(Member {
             avatar: None,
             communication_disabled_until: None,
             deaf: false,
-            guild_id: GuildId::new(1).expect("non zero"),
+            guild_id: Id::new(1),
             joined_at,
             mute: false,
             nick: Some("member nick".to_owned()),
@@ -96,13 +101,13 @@ pub fn cache_with_message_and_reactions() -> InMemoryCache {
             roles: Vec::new(),
             user: User {
                 accent_color: None,
-                avatar: Some("".to_owned()),
+                avatar: Some(avatar),
                 banner: None,
                 bot: false,
                 discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId::new(3).expect("non zero"),
+                id: Id::new(3),
                 locale: None,
                 mfa_enabled: None,
                 name: "test".to_owned(),
@@ -112,17 +117,20 @@ pub fn cache_with_message_and_reactions() -> InMemoryCache {
                 verified: None,
             },
         }),
-        message_id: MessageId::new(4).expect("non zero"),
-        user_id: UserId::new(3).expect("non zero"),
+        message_id: Id::new(4),
+        user_id: Id::new(3),
     });
 
     cache.update(&reaction);
 
+    let user_5_input = b"ef678abdee09d8dfb14e83381983d5e4";
+    let user_5_avatar = ImageHash::parse(user_5_input).unwrap();
+
     reaction.member.replace(Member {
         avatar: None,
         communication_disabled_until: None,
         deaf: false,
-        guild_id: GuildId::new(1).expect("non zero"),
+        guild_id: Id::new(1),
         joined_at,
         mute: false,
         nick: None,
@@ -131,13 +139,13 @@ pub fn cache_with_message_and_reactions() -> InMemoryCache {
         roles: Vec::new(),
         user: User {
             accent_color: None,
-            avatar: Some("".to_owned()),
+            avatar: Some(user_5_avatar),
             banner: None,
             bot: false,
             discriminator: 2,
             email: None,
             flags: None,
-            id: UserId::new(5).expect("non zero"),
+            id: Id::new(5),
             locale: None,
             mfa_enabled: None,
             name: "test".to_owned(),
@@ -147,7 +155,7 @@ pub fn cache_with_message_and_reactions() -> InMemoryCache {
             verified: None,
         },
     });
-    reaction.user_id = UserId::new(5).expect("non zero");
+    reaction.user_id = Id::new(5);
 
     cache.update(&reaction);
 
@@ -168,7 +176,7 @@ pub fn current_user(id: u64) -> CurrentUser {
         bot: true,
         discriminator: 9876,
         email: None,
-        id: UserId::new(id).expect("non zero"),
+        id: Id::new(id),
         mfa_enabled: true,
         name: "test".to_owned(),
         verified: Some(true),
@@ -179,7 +187,7 @@ pub fn current_user(id: u64) -> CurrentUser {
     }
 }
 
-pub fn emoji(id: EmojiId, user: Option<User>) -> Emoji {
+pub fn emoji(id: Id<EmojiMarker>, user: Option<User>) -> Emoji {
     Emoji {
         animated: false,
         available: true,
@@ -192,9 +200,9 @@ pub fn emoji(id: EmojiId, user: Option<User>) -> Emoji {
     }
 }
 
-pub fn guild_channel_text() -> (GuildId, ChannelId, GuildChannel) {
-    let guild_id = GuildId::new(1).expect("non zero");
-    let channel_id = ChannelId::new(2).expect("non zero");
+pub fn guild_channel_text() -> (Id<GuildMarker>, Id<ChannelMarker>, GuildChannel) {
+    let guild_id = Id::new(1);
+    let channel_id = Id::new(2);
     let channel = GuildChannel::Text(TextChannel {
         guild_id: Some(guild_id),
         id: channel_id,
@@ -213,7 +221,7 @@ pub fn guild_channel_text() -> (GuildId, ChannelId, GuildChannel) {
     (guild_id, channel_id, channel)
 }
 
-pub fn member(id: UserId, guild_id: GuildId) -> Member {
+pub fn member(id: Id<UserMarker>, guild_id: Id<GuildMarker>) -> Member {
     let joined_at = Timestamp::from_secs(1_632_072_645).expect("non zero");
 
     Member {
@@ -231,7 +239,7 @@ pub fn member(id: UserId, guild_id: GuildId) -> Member {
     }
 }
 
-pub fn role(id: RoleId) -> Role {
+pub fn role(id: Id<RoleMarker>) -> Role {
     Role {
         color: 0,
         hoist: false,
@@ -248,9 +256,9 @@ pub fn role(id: RoleId) -> Role {
 }
 
 pub fn voice_state(
-    guild_id: GuildId,
-    channel_id: Option<ChannelId>,
-    user_id: UserId,
+    guild_id: Id<GuildMarker>,
+    channel_id: Option<Id<ChannelMarker>>,
+    user_id: Id<UserMarker>,
 ) -> VoiceState {
     VoiceState {
         channel_id,
@@ -270,11 +278,14 @@ pub fn voice_state(
     }
 }
 
-pub fn user(id: UserId) -> User {
+pub fn user(id: Id<UserMarker>) -> User {
+    let banner_hash = b"16ed037ab6dae5e1739f15c745d12454";
+    let banner = ImageHash::parse(banner_hash).expect("valid hash");
+
     User {
         accent_color: None,
         avatar: None,
-        banner: Some("06c16474723fe537c283b8efa61a30c8".to_owned()),
+        banner: Some(banner),
         bot: false,
         discriminator: 1,
         email: None,
